var wpvgw_post_view;

(function ($) {

	wpvgw_post_view = {

		// is Gutenberg editor enabled?
		isGutenbergEditor: false,


		/**
		 * Initializes this object.
		 */
		init: function () {
			this.isGutenbergEditor = $('#editor.gutenberg__editor').length === 1;

			this.hideShowControls();

			this.refreshCharacterCountLinkDisabled = false;

			// refresh character count link (button like)
			this.spinnerRefreshCharacterCount = $('#wpvgw_refresh_character_count_spinner');
			this.linkRefreshCharacterCount = $('#wpvgw_refresh_character_count');
			this.linkRefreshCharacterCount.click(function (e) {
				e.preventDefault();

				if (!wpvgw_post_view.linkRefreshCharacterCount.hasClass('wpvgw-disabled')) {
					// disable refresh character count link
					wpvgw_post_view.linkRefreshCharacterCount.addClass('wpvgw-disabled');
					// show spinner
					wpvgw_post_view.spinnerRefreshCharacterCount.show();
				}

				// update link disabled?
				if (wpvgw_post_view.refreshCharacterCountLinkDisabled)
					return;

				// reset timer
				wpvgw_post_view.printCharacterCount(false);
			});

			// show spinner
			this.spinnerRefreshCharacterCount.show();
			this.spinnerRefreshCharacterCount.css('visibility', 'visible');
			// disable refresh character count link
			this.linkRefreshCharacterCount.addClass('wpvgw-disabled');
			// start timer after 2 s
			//this.printCharacterCount(true);
			//this.printCharacterCountTimer();
			// TODO: hack, 2 s delay to initialize tiny mce or textarea
			setTimeout(function () {
				wpvgw_post_view.printCharacterCount(true)
			}, 2000);


			// Gutenberg editor saving event
			if (this.isGutenbergEditor) {
				var editPost = wp.data.select('core/edit-post');
				var lastIsSaving = false;

				wp.data.subscribe(function () {
					var isSaving = editPost.isSavingMetaBoxes();
					if (isSaving !== lastIsSaving && !isSaving) {
						lastIsSaving = isSaving;
						// Assume saving has finished
						// print character count
						wpvgw_post_view.printCharacterCount(true);
					}

					lastIsSaving = isSaving;
				});
			}

		},

		/**
		 * Hides or shows controls in the VG WORT meta box depend on marker check box.
		 */
		hideShowControls: function () {
			// find marker check box
			var checkBoxSetMarker = $('#wpvgw_set_marker');
			var checkBoxAutoMarker = $('#wpvgw_auto_marker');

			// test if marker check box was found
			if (checkBoxSetMarker.length === 0)
				return;

			// find controls to hide by CSS class
			var trAddMarkerToPost = $('#wpvgw_add_marker_to_post');

			// hide controls if marker check box is not checked
			if (!checkBoxSetMarker.prop('checked'))
				trAddMarkerToPost.hide();

			// bind show and hide controls to marker check box click event
			checkBoxSetMarker.click(function () {
				if ($(this).prop('checked')) {
					trAddMarkerToPost.show();
				} else {
					trAddMarkerToPost.hide();
				}
			});


			// show hide manual marker
			var divManualMarker = $('#wpvgw_manual_marker');
			var hideManualMarkerFunction = function () {
				if (checkBoxAutoMarker.prop('checked')) {
					divManualMarker.hide();
				} else {
					divManualMarker.show();
				}
			};

			// initial hide
			hideManualMarkerFunction();

			// bind show and hide controls to auto marker check box click event
			checkBoxAutoMarker.click(hideManualMarkerFunction);
		},

		/**
		 * Sets a timer to refresh the character count for the current post.
		 */
		printCharacterCountTimer: function () {
			setTimeout(function () {
				wpvgw_post_view.printCharacterCount(true)
			}, 10000);
		},

		/**
		 * Outputs the character count for the current post.
		 */
		printCharacterCount: function (resetTimer) {
			// disable update link
			this.refreshCharacterCountLinkDisabled = true;

			var postTitle = this.isGutenbergEditor ? wp.data.select('core/editor').getEditedPostAttribute('title') : $('#title').val();
			if (postTitle == null)
				postTitle = "";

			// get post content from tiny mce
			if (!this.isGutenbergEditor)
				if (typeof tinyMCE !== 'undefined' && tinyMCE.activeEditor && !tinyMCE.activeEditor.isHidden()) {
					// save tiny mce content to textarea
					tinyMCE.triggerSave();
				}

			// get post content
			//var postContent = this.isGutenbergEditor ? $('textarea[id^=post-content-]').val() : $('#content').val();
			var postContent = this.isGutenbergEditor ? wp.data.select('core/editor').getEditedPostAttribute('content') : $('#content').val();
			if (postContent == null)
				postContent = "";

			// get post excerpt
			var postExcerpt = this.isGutenbergEditor ? wp.data.select('core/editor').getEditedPostAttribute('excerpt') : $('#excerpt').val();
			if (postExcerpt == null)
				postExcerpt = "";

			// collect AJAX post data
			var ajaxPostData = {
				action: 'wpvgw_get_character_count',
				wpvgw_post_title: postTitle,
				wpvgw_post_content: postContent,
				wpvgw_post_excerpt: postExcerpt,
				/**
				 * Get additional data related to the current post. This data will be submitted by the character count calculation ajax call.
				 *
				 * @returns object An custom object.
				 */
				/*function wpvgw_post_get_custom_object () {
				 	return {'custom_field1' : 'Jahr um Jahr musste ich', 'custom_field2' : 'zum Geigenunterricht.'};
				 }*/
				wpvgw_post_custom_object: (typeof wpvgw_post_get_custom_object === "function" ? wpvgw_post_get_custom_object() : null)
			};


			// post AJAX data to WordPress AJAX url
			// noinspection JSUnresolvedVariable
			$.post(wpvgw_ajax_object.ajax_url, ajaxPostData,
					/**
					 * @param response AJAX response as JSON string.
					 */
					function (response) {
						var data = response;

						// output post character count data
						// noinspection JSUnresolvedVariable
						$('#wpvgw_character_count').html(data.character_count);
						// noinspection JSUnresolvedVariable
						$('#wpvgw_character_count_sufficient').html(data.character_count_sufficient);
						// noinspection JSUnresolvedVariable
						$('#wpvgw_missing_character_count').html(data.missing_character_count);
						// noinspection JSUnresolvedVariable
						$('#wpvgw_minimum_character_count').html(data.minimum_character_count);


						// reset timer
						if (resetTimer)
							wpvgw_post_view.printCharacterCountTimer();

						// enable update link
						wpvgw_post_view.refreshCharacterCountLinkDisabled = false;
						// enable refresh character count link
						wpvgw_post_view.linkRefreshCharacterCount.removeClass('wpvgw-disabled');
						// hide spinner
						wpvgw_post_view.spinnerRefreshCharacterCount.hide();
					}
			);
		}

	};

	// bind to document ready function
	$(document).ready(function () {
		wpvgw_post_view.init();
	});

}(jQuery));
